@@ -3,5 +3,7 @@ from .cntv import cntv
 from .mgtv import mgtv
 from .migu import migu
 from .acfun import acfun
+from .zhihu import zhihu
 from .douyin import douyin
-from .haokan import haokan
\ No newline at end of file
+from .haokan import haokan
+from .bilibili import bilibili
\ No newline at end of file
